==> haskell-rfc5051-0.1.0.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rfc5051
version: 0.1.0.3
id: rfc5051-0.1.0.3-5nbjhlUEbi2K2928kSmVvd
key: rfc5051-0.1.0.3-5nbjhlUEbi2K2928kSmVvd
license: BSD3
copyright: (C) 2013 John MacFarlane
maintainer: jgm@berkeley.edu
synopsis: Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.
    .
    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    .
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@
    .
    Here is the same list sorted by @sortBy compareUnicode@:
    .
    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Data.RFC5051
hidden-modules: Data.RFC5051.UnicodeData Data.RFC5051.Types
abi: 908d8c6b1983e44b2bccd7af4b12c9e0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/rfc5051-0.1.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/rfc5051-0.1.0.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/rfc5051-0.1.0.3
hs-libraries: HSrfc5051-0.1.0.3-5nbjhlUEbi2K2928kSmVvd
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html: /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rfc5051-0.1.0.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rfc5051
version: 0.1.0.3
id: rfc5051-0.1.0.3-8AqfZcq7toaE5fd5QrfKKT
key: rfc5051-0.1.0.3-8AqfZcq7toaE5fd5QrfKKT
license: BSD3
copyright: (C) 2013 John MacFarlane
maintainer: jgm@berkeley.edu
synopsis: Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.
    .
    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    .
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@
    .
    Here is the same list sorted by @sortBy compareUnicode@:
    .
    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Data.RFC5051
hidden-modules: Data.RFC5051.UnicodeData Data.RFC5051.Types
abi: 094b2f6031c6bf1316069b04c30a1548
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/rfc5051-0.1.0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/rfc5051-0.1.0.3
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/rfc5051-0.1.0.3
hs-libraries: HSrfc5051-0.1.0.3-8AqfZcq7toaE5fd5QrfKKT
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html: /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
